summaryrefslogtreecommitdiffstats
path: root/server/src/com/vaadin/ui/TabSheet.java
diff options
context:
space:
mode:
authorArtur Signell <artur@vaadin.com>2012-11-22 14:31:53 +0200
committerVaadin Code Review <review@vaadin.com>2012-11-22 14:09:30 +0000
commit7c22ebd68c71cd88b4bc42438df778c7c20e4aae (patch)
tree0d50eb38ba49fe25e294a5fc68b7aa2e9742dd66 /server/src/com/vaadin/ui/TabSheet.java
parent66b1aa488099e8e79c3fb2fb1f0236c29f15f848 (diff)
downloadvaadin-framework-7c22ebd68c71cd88b4bc42438df778c7c20e4aae.tar.gz
vaadin-framework-7c22ebd68c71cd88b4bc42438df778c7c20e4aae.zip
Added Component constructors (#10246)
Change-Id: I86845693004fcdf65d5307c47a27e7d3a3274c52
Diffstat (limited to 'server/src/com/vaadin/ui/TabSheet.java')
-rw-r--r--server/src/com/vaadin/ui/TabSheet.java14
1 files changed, 13 insertions, 1 deletions
diff --git a/server/src/com/vaadin/ui/TabSheet.java b/server/src/com/vaadin/ui/TabSheet.java
index 995db5092e..5553bf64f8 100644
--- a/server/src/com/vaadin/ui/TabSheet.java
+++ b/server/src/com/vaadin/ui/TabSheet.java
@@ -108,7 +108,7 @@ public class TabSheet extends AbstractComponentContainer implements Focusable,
private int tabIndex;
/**
* Constructs a new Tabsheet. Tabsheet is immediate by default, and the
* default close handler removes the tab being closed.
*/
public TabSheet() {
@@ -126,6 +126,18 @@ public class TabSheet extends AbstractComponentContainer implements Focusable,
}
/**
+ * Constructs a new TabSheet containing the given components.
+ *
+ * @param components
+ * The components to add to the tab sheet. Each component will be
+ * added to a separate tab.
+ */
+ public TabSheet(Component... components) {
+ this();
+ addComponents(components);
+ }
+
+ /**
* Gets the component container iterator for going through all the
* components (tab contents).
*
@@ -108,7 +108,7 @@ public class TabSheet extends AbstractComponentContainer implements Focusable,
private int tabIndex;
/**
- * Constructs a new Tabsheet. Tabsheet is immediate by default, and the
+ * Constructs a new TabSheet. A TabSheet is immediate by default, and the
* default close handler removes the tab being closed.
*/